pub struct InputLayerDescription {
pub layer_id: LayerId,
pub num_vars: usize,
}Expand description
The verifier’s view of an input layer during circuit proving, containing the shape information of this input layer.
Fields
layer_id: LayerIdThe layer ID of the input layer.
num_vars: usizeThe number of variables in the input layer.